@@ -15,6 +15,8 @@ apval_Bai1996 <- function(sam1, sam2){
 	names(pval) <- "Bai1996"
 	out <- NULL
 	out$sam.info <- c("n1" = n1, "n2" = n2, "p" = p)
+	out$cov.assumption <- "the two groups have same covariance"
+	out$method <- "asymptotic distribution"
 	out$pval <- pval
 	return(out)
 }
\ No newline at end of file
