@@ -10,7 +10,7 @@ apval_Sri2008 <- function(sam1, sam2){
 	c <- 1 + trR2/p^(3/2)
 	diff <- colMeans(sam1) - colMeans(sam2)
 	diag.sam <- diag(sam.cov)
-	diag.sam[diag.sam == 0] <- 10^(-10)
+	diag.sam[diag.sam <= 10^(-10)] <- 10^(-10)
 	XX <- sum(diff^2/diag.sam)
 	test.stat <- (tau*XX - n*p/(n - 2))/sqrt(2*(trR2 - p^2/n)*c)
 	test.stat <- as.numeric(test.stat)
@@ -18,6 +18,8 @@ apval_Sri2008 <- function(sam1, sam2){
 	names(pval) <- "Sri2008"
 	out <- NULL
 	out$sam.info <- c("n1" = n1, "n2" = n2, "p" = p)
+	out$cov.assumption <- "the two groups have same covariance"
+	out$method <- "asymptotic distribution"
 	out$pval <- pval
 	return(out)
 }
\ No newline at end of file
