@@ -4,7 +4,7 @@ max_threshold <- function(sample1, sample2, sig_mat){
 	b_f <- 2*log(log(p)) + 0.5*log(log(log(p))) - 0.5*log(4*3.1416/(1 - 0.05)^2)
 	eta <- 0.05
 	diag.sig <- diag(sig_mat)
-	diag.sig[diag.sig == 0] <- 10^(-10)
+	diag.sig[diag.sig <= 10^(-10)] <- 10^(-10)
 	T_orig <- (colMeans(sample1) - colMeans(sample2))^2/((1/n1 + 1/n2)*diag.sig)
 	s_level <- T_orig[sign(T_orig) >= 0.01 & T_orig <= 2*(1 - eta)*log(p)]
 	s_m <- matrix(s_level, length(s_level), p, byrow = F)
